﻿using System;
using System.Data;
using System.IO;
using System.Text;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using BalCoding.DurableDNSApi.DataAccess;

namespace DurableDNSApiTest
{
	/// <summary>
	/// Summary description for BalDnsExampleTests
	/// </summary>
	[TestClass]
	public class BalDnsExampleTests
	{
		private const string _sUser = "L2";
		private const string _sKey = "wG";

		public BalDnsExampleTests()
		{
			//
			// TODO: Add constructor logic here
			//
		}

		private TestContext testContextInstance;

		/// <summary>
		///Gets or sets the test context which provides
		///information about and functionality for the current test run.
		///</summary>
		public TestContext TestContext
		{
			get
			{
				return testContextInstance;
			}
			set
			{
				testContextInstance = value;
			}
		}

		#region Additional test attributes
		//
		// You can use the following additional attributes as you write your tests:
		//
		// Use ClassInitialize to run code before running the first test in the class
		// [ClassInitialize()]
		// public static void MyClassInitialize(TestContext testContext) { }
		//
		// Use ClassCleanup to run code after all tests in a class have run
		// [ClassCleanup()]
		// public static void MyClassCleanup() { }
		//
		// Use TestInitialize to run code before running each test 
		// [TestInitialize()]
		// public void MyTestInitialize() { }
		//
		// Use TestCleanup to run code after each test has run
		// [TestCleanup()]
		// public void MyTestCleanup() { }
		//
		#endregion

		[TestMethod]
		public void UpdateAllRecordTTLTest()
		{
			string lsUser = _sUser;
			string lsKey = _sKey;
			string[] laZones = BalDnsZoneRepository.SelectNames(lsUser, lsKey);
			foreach (string lsZone in laZones)
			{
				int[] laIds = BalDnsRecordRepository.SelectIds(lsUser, lsKey, lsZone);
				foreach (int lnId in laIds)
				{
					DataTable loTable = BalDnsRecordRepository.Select(lsUser, lsKey, lsZone, lnId);
					if ((int)loTable.Rows[0][BalDnsRecordRepository.RecordMap.TTL] != 172800)
					{
						loTable.Rows[0][BalDnsRecordRepository.RecordMap.TTL] = 172800; //2 days
						BalDnsRecordRepository.Update(lsUser, lsKey, lsZone, lnId, loTable);
					}
				}
			}
		}

		[TestMethod]
		public void UpdateAllZoneSOATest()
		{
			string lsUser = _sUser;
			string lsKey = _sKey;
			string[] laZones = BalDnsZoneRepository.SelectNames(lsUser, lsKey);
			SortedList<string, bool> loList = new SortedList<string, bool>();
			foreach (string lsZone in laZones)
			{
				loList.Add(lsZone, true);
			}
			foreach (string lsZone in loList.Keys)
			{
				DataTable loTable = BalDnsZoneRepository.Select(lsUser, lsKey, lsZone);
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.Email] = "hostmaster.balhosting.net.";
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.Expire] = 1209600; //2 weeks
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.Minimum] = 3600; //1 hour
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.NameServer] = "ns1.balhosting.net.";
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.Refresh] = 3600; //1 hour
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.Retry] = 600; //10 minutes
				loTable.Rows[0][BalDnsZoneRepository.ZoneMap.TTL] = 1209600; //2 weeks
				BalDnsZoneRepository.Update(lsUser, lsKey, lsZone, loTable);
			}
		}

		/// <summary>
		///A test for Full backup
		///</summary>
		[TestMethod()]
		public void FullBackupTest()
		{
			string lsRecordFile = @"C:\temp\DnsRecords.txt";
			string lsZoneFile = @"C:\temp\DnsZones.txt";
			string lsUser = _sUser;
			string lsKey = _sKey;
			string[] laZones = BalDnsZoneRepository.SelectNames(lsUser, lsKey);
			SortedList<string, bool> loList = new SortedList<string, bool>();
			foreach (string lsZone in laZones)
			{
				loList.Add(lsZone, true);
			}
			if (!File.Exists(lsRecordFile))
			{
				string lsHeader = "Zone\tType\tName\tData\tAux\tTTL\tDDNS\tId\r\n";
				File.WriteAllText(lsRecordFile, lsHeader);
			}
			if (!File.Exists(lsZoneFile))
			{
				string lsHeader = "Zone\tNameServer\tEmail\tXfer\tUpdateAcl\tSerial\tRefresh\tRetry\tExpire\tMinimun\tTTL\r\n";
				File.WriteAllText(lsZoneFile, lsHeader);
			}
			string[] laCurrent = File.ReadAllLines(lsRecordFile);
			foreach (string lsZone in loList.Keys)
			{
				bool lbFound = false;
				foreach (string lsCurrent in laCurrent)
				{
					if (lsCurrent.StartsWith(lsZone))
					{
						lbFound = true;
					}
				}

				if (!lbFound)
				{
					DataTable loZoneTable = BalDnsZoneRepository.Select(lsUser, lsKey, lsZone);
					string lsZoneLine = lsZone + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.NameServer].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Email].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Xfer].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.UpdateACL].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Serial].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Refresh].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Retry].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Expire].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.Minimum].ToString() + "\t";
					lsZoneLine += loZoneTable.Rows[0][BalDnsZoneRepository.ZoneMap.TTL].ToString() + "\r\n";
					File.AppendAllText(lsZoneFile, lsZoneLine);

					int[] laIds = BalDnsRecordRepository.SelectIds(lsUser, lsKey, lsZone);
					foreach (int lnId in laIds)
					{
						DataTable loTable = BalDnsRecordRepository.Select(lsUser, lsKey, lsZone, lnId);
						string lsRecord = lsZone + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.Type] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.Name] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.Data] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.Aux] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.TTL] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.DDNS] + "\t";
						lsRecord += loTable.Rows[0][BalDnsRecordRepository.RecordMap.Id] + "\r\n";
						File.AppendAllText(lsRecordFile, lsRecord);
					}
				}
			}
		}
	}
}
